@@ -244,11 +244,13 @@ class SencyberLogger:
 
             client.settimeout(10)
             client.send(b"\x55\xAASTT\xED")
-            dat = client.recv(10)
+            dat = client.recv(6)
+            logging.log(f"Recv: {dat}")
             if dat == b"\x55\xAARCV\xED":
                 file_path = f"{self.file_name}.log"
                 if not os.path.exists(file_path):
                     logging.error(f"{file_path} Not Exist")
+                    client.close()
                     return 1
                 with open(file_path, 'r') as f:
                     data = f.read().encode(encoding="utf-8")
@@ -278,7 +280,7 @@ class SencyberLogger:
             print(f"Connection Reset By Peer.")
             client.close()
             return 1
-        except TimeoutError:
+        except socket.timeout:
             logging.error(f"Connection Time Out.")
             print(f"Connection Time Out.")
             client.close()
@@ -340,10 +342,11 @@ class SencyberLoggerReceiver:
         try:
             conn.settimeout(10)
             data = conn.recv(6)
+            logging.debug(f"Recv: {data}")
             if data == b"\x55\xAASTT\xED":
-                conn.settimeout(10)
                 conn.send(b"\x55\xAARCV\xED")
 
+                conn.settimeout(10)
                 s_header = conn.recv(4)
                 s_header = struct.unpack('i', s_header)[0]
 
@@ -361,6 +364,7 @@ class SencyberLoggerReceiver:
                 res = b""
                 size = 0
                 while size < file_size:
+                    print(f"{size} vs. {file_size}")
                     data = conn.recv(2048)
                     size += len(data)
                     res += data
